CountUpConfig class

CountUpConfig class contains configuration options for count up durations.

Annotations

Constructors

CountUpConfig({required Duration initialDuration, Duration? maxDuration})
CountUpConfig class contains configuration options for count up durations.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
initialDuration Duration
initial duration countup start
final
isInfinity bool
isInfinity true if maxduration is null count up will infinit
no setter
maxDuration Duration?
if the maxDuration is null countUp will infinity
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Duration? initialDuration, Duration? maxDuration}) CountUpConfig
copyWith
isDone(Duration duration) bool
isDone true if current duration same as max duration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(covariant CountUpConfig other) bool
The equality operator.
override

Constants

defaultConfig → const CountUpConfig
default config