style property
TextStyle is a parameter for all existing text, if this is null SlideCountdown has a default text style which will be of all text
Implementation
final TextStyle style;
TextStyle is a parameter for all existing text, if this is null SlideCountdown has a default text style which will be of all text
final TextStyle style;